@@ -100,7 +100,7 @@ void GeneratorPrivate::pixmapGenerationFinished()
     }
 
     const QImage& img = mPixmapGenerationThread->image();
-    request->page()->setPixmap( request->id(), new QPixmap( QPixmap::fromImage( img ) ) );
+    request->page()->setPixmap( request->id(), new QPixmap( QPixmap::fromImage( img ) ), request->normalizedRect() );
     const int pageNumber = request->page()->number();
 
     if ( mPixmapGenerationThread->calcBoundingBox() )
@@ -236,7 +236,7 @@ void Generator::generatePixmap( PixmapRequest *request )
     }
 
     const QImage& img = image( request );
-    request->page()->setPixmap( request->id(), new QPixmap( QPixmap::fromImage( img ) ) );
+    request->page()->setPixmap( request->id(), new QPixmap( QPixmap::fromImage( img ) ), request->normalizedRect() );
     const bool bboxKnown = request->page()->isBoundingBoxKnown();
     const int pageNumber = request->page()->number();
 
@@ -431,6 +431,8 @@ PixmapRequest::PixmapRequest( int id, int pageNumber, int width, int height, int
     d->mPriority = priority;
     d->mAsynchronous = asynchronous;
     d->mForce = false;
+    d->mTile = false;
+    d->mNormalizedRect = NormalizedRect();
 }
 
 PixmapRequest::~PixmapRequest()
@@ -473,6 +475,29 @@ Page* PixmapRequest::page() const
     return d->mPage;
 }
 
+void PixmapRequest::setTile( bool tile )
+{
+    d->mTile = tile;
+}
+
+bool PixmapRequest::isTile() const
+{
+    return d->mTile;
+}
+
+void PixmapRequest::setNormalizedRect( const NormalizedRect &rect )
+{
+    if ( d->mNormalizedRect == rect )
+        return;
+
+    d->mNormalizedRect = rect;
+}
+
+const NormalizedRect& PixmapRequest::normalizedRect() const
+{
+    return d->mNormalizedRect;
+}
+
 void PixmapRequestPrivate::swap()
 {
     qSwap( mWidth, mHeight );
